@@ -277,30 +277,83 @@ class SSHClient(object):
 
     @enter_and_leave_function
     def _scp_to_remote(self, local_path, remote_path):
-        log.info(
-            f" {self.__ip}:{self.__port} | Begin to copy file from local {local_path} to remote host {remote_path}.")
-        self.__sftp.put(local_path, remote_path)
-        rs = self.exec(f"ls {remote_path}")
-        if rs.exit_status_code == 0:
-            log.info(
-                f" {self.__ip}:{self.__port} | Success to copy file from local {local_path} to remote host{remote_path}: OK.")
+        """递归拷贝本地文件/文件夹到远端"""
+        local_path = Path(local_path).resolve()
+        remote_path = Path(remote_path)
+
+        # 1. 处理本地文件：直接上传
+        if local_path.is_file():
+            log.info(f" {self.__ip}:{self.__port} | Copy file: {local_path} -> {remote_path}")
+            self.__sftp.put(str(local_path), str(remote_path))
+            # 验证文件是否存在
+            rs = self.exec(f"ls {remote_path}")
+            if rs.exit_status_code != 0:
+                log.warning(f" {self.__ip}:{self.__port} | File copy failed: {remote_path} not found")
+                return False
             return True
-        else:
-            log.warning(
-                f" {self.__ip}:{self.__port} | failed to copy file from local {local_path} to remote host{remote_path}:Error.")
-            return False
+
+        # 2. 处理本地文件夹：递归创建远端目录并拷贝所有内容
+        if local_path.is_dir():
+            # 创建远端目录（-p 确保父目录存在，忽略已存在错误）
+            mkdir_cmd = f"mkdir -p {remote_path}"
+            rs = self.exec(mkdir_cmd)
+            if rs.exit_status_code != 0:
+                log.error(f" {self.__ip}:{self.__port} | Failed to create remote dir: {remote_path}, cmd: {mkdir_cmd}")
+                return False
+
+            # 遍历本地文件夹所有内容
+            for root, dirs, files in os.walk(local_path):
+                # 计算远端对应目录路径
+                relative_root = Path(root).relative_to(local_path)
+                remote_root = remote_path / relative_root
+
+                # 创建远端子目录
+                if dirs:
+                    remote_dir_cmd = f"mkdir -p {remote_root}"
+                    self.exec(remote_dir_cmd)
+
+                # 拷贝文件
+                for file in files:
+                    local_file = Path(root) / file
+                    remote_file = remote_root / file
+                    try:
+                        self.__sftp.put(str(local_file), str(remote_file))
+                        log.debug(f" {self.__ip}:{self.__port} | Copied: {local_file} -> {remote_file}")
+                    except Exception as e:
+                        log.error(
+                            f" {self.__ip}:{self.__port} | Copy failed: {local_file} -> {remote_file}, error: {str(e)}")
+                        return False
+
+            log.info(f" {self.__ip}:{self.__port} | Directory copy completed: {local_path} -> {remote_path}")
+            return True
+
+        # 3. 本地路径不存在或不是文件/文件夹
+        log.error(f" {self.__ip}:{self.__port} | Local path invalid: {local_path} (not file/dir)")
+        return False
 
     @enter_and_leave_function
-    def scp_to_remote(self, local_path, remote_path,timeout=120):
+    def scp_to_remote(self, local_path, remote_path, timeout=120):
         try:
             if not self.__ssh:
                 if not self.reconnect():
                     raise RuntimeError("ssh transport is not active and failed to reconnect.")
             if not self.__sftp:
                 self.__sftp = self.__ssh.open_sftp()
+
+            # 转换为 Path 类型，统一路径处理（兼容字符串输入）
+            local_path = Path(local_path)
+            remote_path = Path(remote_path)
+
+            # 优化：如果本地是文件夹，远端路径自动指向目标文件夹（而非文件夹下的文件）
+            if local_path.is_dir() and self.exec(f"test -f {remote_path}").exit_status_code == 0:
+                log.warning(
+                    f" {self.__ip}:{self.__port} | Remote path exists as file: {remote_path}, will overwrite to dir")
+                self.exec(f"rm -f {remote_path}")
+
             return self._scp_to_remote(local_path, remote_path)
         except Exception:
-            log.warning(f"when scp from local {local_path} to remote {remote_path}, meets exception.", exc_info=True)
+            log.warning(f" {self.__ip}:{self.__port} | SCP exception: local {local_path} -> remote {remote_path}",
+                        exc_info=True)
             return False
 
     @enter_and_leave_function
